@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,37 +49,6 @@
 
 package com.openexchange.subscribe.json;
 
-import java.io.IOException;
-import java.io.PrintWriter;
-import java.util.Collection;
-import java.util.Date;
-import javax.servlet.ServletException;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
-import org.json.JSONArray;
-import org.json.JSONException;
-import org.json.JSONObject;
-import com.openexchange.ajax.PermissionServlet;
-import com.openexchange.ajax.container.Response;
-import com.openexchange.ajax.writer.ResponseWriter;
-import com.openexchange.groupware.AbstractOXException;
-import com.openexchange.groupware.container.FolderObject;
-import com.openexchange.groupware.contexts.Context;
-import com.openexchange.groupware.ldap.User;
-import com.openexchange.groupware.ldap.UserStorage;
-import com.openexchange.groupware.userconfiguration.UserConfiguration;
-import com.openexchange.groupware.userconfiguration.UserConfigurationStorage;
-import com.openexchange.groupware.contexts.impl.ContextStorage;
-import com.openexchange.session.Session;
-import com.openexchange.subscribe.SubscribeService;
-import com.openexchange.subscribe.Subscription;
-import com.openexchange.subscribe.SubscriptionHandler;
-import com.openexchange.tools.iterator.SearchIterator;
-import com.openexchange.tools.oxfolder.OXFolderIteratorSQL;
-import com.openexchange.tools.servlet.http.Tools;
-import com.openexchange.tools.session.ServerSession;
 
 /**
  * @author <a href="mailto:martin.herfurth@open-xchange.org">Martin Herfurth</a>
@@ -88,7 +57,7 @@ public class SubscribeJSONServlet {
 
 //    private static final long serialVersionUID = 1L;
 //
-//    private static final Log LOG = LogFactory.getLog(SubscribeJSONServlet.class);
+//    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(SubscribeJSONServlet.class));
 //
 //    private static final int POST = 0;
 //
