@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -86,15 +86,16 @@ import com.openexchange.tools.session.ServerSession;
  */
 public class SubscriptionMultipleHandler implements MultipleHandler {
 
-    private final SubscriptionSourceDiscoveryService discovery;
     private final SubscriptionExecutionService executor;
     private final SecretService secretService;
+    private final SubscriptionSourceDiscoveryService discovery;
 
     public static final Set<String> ACTIONS_REQUIRING_BODY = new HashSet<String>() {{
        add("new");
        add("update");
        add("delete");
        add("list");
+       add("fetch");
     }};
     
     public SubscriptionMultipleHandler(final SubscriptionSourceDiscoveryService discovery, final SubscriptionExecutionService executor, final SecretService secretService) {
@@ -130,11 +131,13 @@ public class SubscriptionMultipleHandler implements MultipleHandler {
             } else if (action.equals("get")) {
                 return loadSubscription(request, session);
             } else if (action.equals("all")) {
-                return loadAllSubscriptionsInFolder(request, session);
+                return loadAllSubscriptions(request, session);
             } else if (action.equals("list")) {
                 return listSubscriptions(request, session);
             } else if (action.equals("refresh")) {
                 return refreshSubscriptions(request, session);
+            } else if (action.equals("fetch")) {
+                return fetchSubscription(request, session);
             } else {
                 UNKNOWN_ACTION.throwException(action);
                 return null;
@@ -148,14 +151,19 @@ public class SubscriptionMultipleHandler implements MultipleHandler {
         }
     }
 
+    private Object fetchSubscription(JSONObject request, ServerSession session) throws JSONException, AbstractOXException {
+        final Subscription subscription = getSubscription(request, session, secretService.getSecret(session));
+        subscription.setId(-1);
+        return executor.executeSubscriptions(Arrays.asList(subscription), session);
+    }
+
     private Object refreshSubscriptions(final JSONObject request, final ServerSession session) throws AbstractOXException, JSONException {
         final List<Subscription> subscriptionsToRefresh = new ArrayList<Subscription>(10);
-        final Context context = session.getContext();
         final Set<Integer> ids = new HashSet<Integer>();
         if (request.has("folder")) {
             final String folderId = request.getString("folder");
             List<Subscription> allSubscriptions = null;
-            allSubscriptions = getSubscriptionsInFolder(context, folderId, secretService.getSecret(session));
+            allSubscriptions = getSubscriptionsInFolder(session, folderId, secretService.getSecret(session));
             Collections.sort(allSubscriptions, new Comparator<Subscription>() {
 
                 public int compare(Subscription o1, Subscription o2) {
@@ -173,17 +181,14 @@ public class SubscriptionMultipleHandler implements MultipleHandler {
         }
         if (request.has("id")) {
             final int id = request.getInt("id");
-            final Subscription subscription = loadSubscription(id, context, request.optString("source"), secretService.getSecret(session));
+            final Subscription subscription = loadSubscription(id, session, request.optString("source"), secretService.getSecret(session));
             if (!ids.contains(id)) {
                 ids.add(id);
                 subscriptionsToRefresh.add(subscription);
             }
         }
-
-        executor.executeSubscriptions(subscriptionsToRefresh);
         
-        
-        return 1;
+        return executor.executeSubscriptions(subscriptionsToRefresh, session);
     }
 
 
@@ -193,7 +198,7 @@ public class SubscriptionMultipleHandler implements MultipleHandler {
         final List<Subscription> subscriptions = new ArrayList<Subscription>(ids.length());
         for (int i = 0, size = ids.length(); i < size; i++) {
             final int id = ids.getInt(i);
-            final SubscriptionSource source = discovery.getSource(context, id);
+            final SubscriptionSource source = getDiscovery(session).getSource(context, id);
             if(source != null) {
                 final SubscribeService subscribeService = source.getSubscribeService();
                 final Subscription subscription = subscribeService.loadSubscription(context, id, secretService.getSecret(session));
@@ -209,12 +214,22 @@ public class SubscriptionMultipleHandler implements MultipleHandler {
         return createResponse(subscriptions, basicColumns, dynamicColumns, dynamicColumnOrder);
     }
 
-    private Object loadAllSubscriptionsInFolder(final JSONObject request, final ServerSession session) throws JSONException, AbstractOXException {
-        final String folderId = request.getString("folder");
+    private Object loadAllSubscriptions(final JSONObject request, final ServerSession session) throws JSONException, AbstractOXException {
+        String folderId = null;
+        boolean containsFolder = false;
+        if (request.has("folder")) {
+            folderId = request.getString("folder");
+            containsFolder = true;
+        }
+        
         final Context context = session.getContext();
 
         List<Subscription> allSubscriptions = null;
-        allSubscriptions = getSubscriptionsInFolder(context, folderId, secretService.getSecret(session));
+        if (containsFolder) {
+            allSubscriptions = getSubscriptionsInFolder(session, folderId, secretService.getSecret(session));
+        } else {
+            allSubscriptions = getAllSubscriptions(session, secretService.getSecret(session));
+        }       
 
         final String[] basicColumns = getBasicColumns(request);
         final Map<String, String[]> dynamicColumns = getDynamicColumns(request);
@@ -223,15 +238,27 @@ public class SubscriptionMultipleHandler implements MultipleHandler {
         return createResponse(allSubscriptions, basicColumns, dynamicColumns, dynamicColumnOrder);
     }
 
-    private List<Subscription> getSubscriptionsInFolder(final Context context, final String folder, final String secret) throws AbstractOXException {
-        final List<SubscriptionSource> sources = discovery.getSources();
+    private List<Subscription> getSubscriptionsInFolder(final ServerSession session, final String folder, final String secret) throws AbstractOXException {
+        final List<SubscriptionSource> sources = getDiscovery(session).getSources();
         final List<Subscription> allSubscriptions = new ArrayList<Subscription>(10);
         for (final SubscriptionSource subscriptionSource : sources) {
-            final Collection<Subscription> subscriptions = subscriptionSource.getSubscribeService().loadSubscriptions(context, folder, secret);
+            final Collection<Subscription> subscriptions = subscriptionSource.getSubscribeService().loadSubscriptions(session.getContext(), folder, secret);
             allSubscriptions.addAll(subscriptions);
         }
         return allSubscriptions;
     }
+    
+    private List<Subscription> getAllSubscriptions(final ServerSession session, final String secret) throws AbstractOXException {
+        final List<SubscriptionSource> sources = getDiscovery(session).getSources();
+        final List<Subscription> allSubscriptions = new ArrayList<Subscription>();
+        for (final SubscriptionSource subscriptionSource : sources) {
+            final SubscribeService subscribeService = subscriptionSource.getSubscribeService();
+            final Collection<Subscription> subscriptions = subscribeService.loadSubscriptions(session.getContext(), session.getUserId(), secret);
+            allSubscriptions.addAll(subscriptions);
+        }
+        
+        return allSubscriptions;
+    }
 
     private Object createResponse(final List<Subscription> allSubscriptions, final String[] basicColumns, final Map<String, String[]> dynamicColumns, final List<String> dynamicColumnOrder) throws SubscriptionJSONException, JSONException {
         final JSONArray rows = new JSONArray();
@@ -289,7 +316,7 @@ public class SubscriptionMultipleHandler implements MultipleHandler {
     private String[] getBasicColumns(final JSONObject request) {
         final String columns = request.optString("columns");
         if (columns == null || columns.equals("")) {
-            return new String[] { "id", "folder", "source" };
+            return new String[] { "id", "folder", "source", "displayName", "enabled" };
         }
         return columns.split("\\s*,\\s*");
     }
@@ -297,32 +324,34 @@ public class SubscriptionMultipleHandler implements MultipleHandler {
     private Object loadSubscription(final JSONObject request, final ServerSession session) throws JSONException, AbstractOXException {
         final int id = request.getInt("id");
         final String source = request.optString("source");
-        final Context context = session.getContext();
-        final Subscription subscription = loadSubscription(id, context, source, secretService.getSecret(session));
+        final Subscription subscription = loadSubscription(id, session, source, secretService.getSecret(session));
         return createResponse(subscription, request.optString("__serverURL"));
     }
 
     private Object createResponse(final Subscription subscription, final String urlPrefix) throws JSONException, SubscriptionJSONException {
+        if (subscription == null) {
+            return new JSONObject();
+        }
         final JSONObject object = new SubscriptionJSONWriter().write(subscription, subscription.getSource().getFormDescription(), urlPrefix);
         return object;
     }
 
-    private Subscription loadSubscription(final int id, final Context context, final String source, final String secret) throws AbstractOXException {
+    private Subscription loadSubscription(final int id, final ServerSession session, final String source, final String secret) throws AbstractOXException {
         SubscribeService service = null;
         if (source != null && !source.equals("")) {
-            final SubscriptionSource s = discovery.getSource(source);
+            final SubscriptionSource s = getDiscovery(session).getSource(source);
             if(s == null) {
                 return null;
             }
             service = s.getSubscribeService();
         } else {
-            final SubscriptionSource s = discovery.getSource(context, id);
+            final SubscriptionSource s = getDiscovery(session).getSource(session.getContext(), id);
             if(s == null) {
                 return null;
             }
             service = s.getSubscribeService();
         }
-        return service.loadSubscription(context, id, secret);
+        return service.loadSubscription(session.getContext(), id, secret);
     }
 
     private Object deleteSubscriptions(final JSONObject request, final ServerSession session) throws JSONException, AbstractOXException {
@@ -330,7 +359,7 @@ public class SubscriptionMultipleHandler implements MultipleHandler {
         final Context context = session.getContext();
         for (int i = 0, size = ids.length(); i < size; i++) {
             final int id = ids.getInt(i);
-            final SubscriptionSource s = discovery.getSource(context, id);
+            final SubscriptionSource s = getDiscovery(session).getSource(context, id);
             if(s == null) {
                 continue;
             }
@@ -358,13 +387,17 @@ public class SubscriptionMultipleHandler implements MultipleHandler {
         return subscription.getId();
     }
 
-    private Subscription getSubscription(final JSONObject request, final ServerSession session, final String secret) throws JSONException {
+    private Subscription getSubscription(final JSONObject request, final ServerSession session, final String secret) throws JSONException, AbstractOXException {
         final JSONObject object = request.getJSONObject(ResponseFields.DATA);
-        final Subscription subscription = new SubscriptionJSONParser(discovery).parse(object);
+        final Subscription subscription = new SubscriptionJSONParser(getDiscovery(session)).parse(object);
         subscription.setContext(session.getContext());
         subscription.setUserId(session.getUserId());
-        subscription.getConfiguration().put("com.openexchange.crypto.secret", secret);
+        subscription.setSecret(secret);
         return subscription;
     }
 
+    private SubscriptionSourceDiscoveryService getDiscovery(ServerSession session) throws AbstractOXException {
+        return discovery.filter(session.getUserId(), session.getContextId());
+    }
+
 }
